==> glpi-10.0.7.tgz: glpi/install/migrations/update_10.0.6_to_10.0.7/domains_items.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2023 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

/**
 * @var DB $DB
 * @var Migration $migration
 */

if (!$DB->fieldExists(\Domain_Item::getTable(), 'is_dynamic')) {
    $migration->addField(
        \Domain_Item::getTable(),
        'is_dynamic',
        'bool'
    );
    $migration->addKey(
        \Domain_Item::getTable(),
        'is_dynamic'
    );

    $migration->addField(
        \Domain_Item::getTable(),
        'is_deleted',
        'bool'
    );
    $migration->addKey(
        \Domain_Item::getTable(),
        'is_deleted'
    );
}

==> glpi-10.0.11.tgz: glpi/install/migrations/update_10.0.6_to_10.0.7/domains_items.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2023 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

/**
 * @var \DBmysql $DB
 * @var \Migration $migration
 */

if (!$DB->fieldExists(\Domain_Item::getTable(), 'is_dynamic')) {
    $migration->addField(
        \Domain_Item::getTable(),
        'is_dynamic',
        'bool'
    );
    $migration->addKey(
        \Domain_Item::getTable(),
        'is_dynamic'
    );

    $migration->addField(
        \Domain_Item::getTable(),
        'is_deleted',
        'bool'
    );
    $migration->addKey(
        \Domain_Item::getTable(),
        'is_deleted'
    );
}
